<?php

namespace FiloBlu\Storelocator\Block\Adminhtml\Stores\Edit\Tab;

class WorkingTimes extends \Magento\Backend\Block\Widget\Form\Generic implements \Magento\Backend\Block\Widget\Tab\TabInterface
{
    /**
     * @var \Magento\Store\Model\System\Store
     */
    protected $_systemStore;

    /**
     * @param \Magento\Backend\Block\Template\Context $context
     * @param \Magento\Framework\Registry $registry
     * @param \Magento\Framework\Data\FormFactory $formFactory
     * @param \Magento\Cms\Model\Wysiwyg\Config $wysiwygConfig
     * @param \Magento\Store\Model\System\Store $systemStore
     * @param array $data
     */
    public function __construct(
        \Magento\Backend\Block\Template\Context $context,
        \Magento\Framework\Registry $registry,
        \Magento\Framework\Data\FormFactory $formFactory,
        \Magento\Store\Model\System\Store $systemStore,
        array $data = []
    )
    {
        $this->_systemStore = $systemStore;
        parent::__construct($context, $registry, $formFactory, $data);
    }

    /**
     * Init form
     *
     * @return void
     */
    protected function _construct()
    {
        parent::_construct();
        $this->setId('storelocator_store_form_workingtimes');
    }

    /**
     * Prepare form
     *
     * @return $this
     */
    protected function _prepareForm()
    {
        /** @var \FiloBlu\Storelocator\Model\Stores $model */
        $model = $this->_coreRegistry->registry('storelocator_store');

        $storeId = $model->getStoreId();

        $form = $this->_formFactory->create();

        $form->setHtmlIdPrefix('storelocator_store_workingtimes_');

        // ## Working Times ##

        for ($wt = 1; $wt <= 7; $wt++) {

            $dayStr = '';

            switch ($wt) {
                case 1:
                    $dayStr = "monday";
                    break;
                case 2:
                    $dayStr = "tuesday";
                    break;
                case 3:
                    $dayStr = "wednesday";
                    break;
                case 4:
                    $dayStr = "thursday";
                    break;
                case 5:
                    $dayStr = "friday";
                    break;
                case 6:
                    $dayStr = "saturday";
                    break;
                case 7:
                    $dayStr = "sunday";
                    break;

                default:
                    break;
            }

            $fieldset = $form->addFieldset(
                $dayStr . '_fieldset',
                ['legend' => __(ucfirst($dayStr)), 'class' => 'fieldset-wide']
            );

            $fieldset->addField(
                $dayStr . '_morning_time_from',
                'time',
                [
                    'name' => $dayStr . '_morning_time_from',
                    'label' => __('Morning From'),
                    'time_format' => 'hh:mm:ss'
                ]
            );

            $fieldset->addField(
                $dayStr . '_morning_time_to',
                'time',
                [
                    'name' => $dayStr . '_morning_time_to',
                    'label' => __('Morning To'),
                    'time_format' => 'hh:mm:ss'
                ]
            );

            $fieldset->addField(
                'closed_' . $dayStr . '_morning',
                'select',
                [
                    'label' => __('Closed Morning'),
                    'title' => __('Closed Morning'),
                    'name' => 'closed_' . $dayStr . '_morning',
                    'required' => true,
                    'options' => [true => __('Yes'), false => __('No')]
                ]
            );


            $fieldset->addField(
                $dayStr . '_afternoon_time_from',
                'time',
                [
                    'name' => $dayStr . '_afternoon_time_from',
                    'label' => __('Afternoon From'),
                    'time_format' => 'hh:mm:ss'
                ]
            );

            $fieldset->addField(
                $dayStr . '_afternoon_time_to',
                'time',
                [
                    'name' => $dayStr . '_afternoon_time_to',
                    'label' => __('Afternoon To'),
                    'time_format' => 'hh:mm:ss'
                ]
            );

            $fieldset->addField(
                'closed_' . $dayStr . '_afternoon',
                'select',
                [
                    'label' => __('Closed Afternoon'),
                    'title' => __('Closed Afternoon'),
                    'name' => 'closed_' . $dayStr . '_afternoon',
                    'required' => true,
                    'options' => [true => __('Yes'), false => __('No')]
                ]
            );

        }

        if ($storeId) {

            $objDataForm = [];

            $modelWT = \Magento\Framework\App\ObjectManager::getInstance()->get('FiloBlu\Storelocator\Model\WorkingTimes');

            $workingTimesCollection = $modelWT->loadByStoreId($storeId);

            foreach ($workingTimesCollection as $workingTime) {

                $isClosed = $workingTime["closed"];

                $fromHH = "00";
                $fromMM = "00";
                $fromSS = "00";

                if ($workingTime["from"]) {
                    $timeFrom = explode(":", explode(" ", $workingTime["from"])[1]);
                    $fromHH = $timeFrom[0];
                    $fromMM = $timeFrom[1];
                    $fromSS = $timeFrom[2];

                }

                $toHH = "00";
                $toMM = "00";
                $toSS = "00";

                if ($workingTime["to"]) {
                    $timeTo = explode(":", explode(" ", $workingTime["to"])[1]);
                    $toHH = $timeTo[0];
                    $toMM = $timeTo[1];
                    $toSS = $timeTo[2];

                }

                $dayStr = '';

                switch ($workingTime->getDay()) {
                    case 1:
                        $dayStr = "monday";
                        break;
                    case 2:
                        $dayStr = "tuesday";
                        break;
                    case 3:
                        $dayStr = "wednesday";
                        break;
                    case 4:
                        $dayStr = "thursday";
                        break;
                    case 5:
                        $dayStr = "friday";
                        break;
                    case 6:
                        $dayStr = "saturday";
                        break;
                    case 7:
                        $dayStr = "sunday";
                        break;

                    default:
                        break;
                }

                switch ($workingTime->getPeriod()) {
                    case 1:

                        $objDataForm[$dayStr . '_morning_time_from'] = $fromHH . ',' . $fromMM . ',' . $fromSS;
                        $objDataForm[$dayStr . '_morning_time_to'] = $toHH . ',' . $toMM . ',' . $toSS;
                        $objDataForm['closed_' . $dayStr . '_morning'] = $isClosed;

                        break;
                    case 2:

                        $objDataForm[$dayStr . '_afternoon_time_from'] = $fromHH . ',' . $fromMM . ',' . $fromSS;
                        $objDataForm[$dayStr . '_afternoon_time_to'] = $toHH . ',' . $toMM . ',' . $toSS;
                        $objDataForm['closed_' . $dayStr . '_afternoon'] = $isClosed;

                        break;

                    default:
                        break;
                }
            }

            $form->setValues($objDataForm);

        }

        $this->setForm($form);

        return parent::_prepareForm();
    }

    /**
     * Prepare label for tab
     *
     * @return string
     */
    public function getTabLabel()
    {
        return __('Working Times');
    }

    /**
     * Prepare title for tab
     *
     * @return string
     */
    public function getTabTitle()
    {
        return $this->getTabLabel();
    }

    /**
     * Can show tab in tabs
     *
     * @return boolean
     */
    public function canShowTab()
    {
        return true;
    }

    /**
     * Tab is hidden
     *
     * @return boolean
     */
    public function isHidden()
    {
        return false;
    }

    protected function _formatTime()
    {
        return "";
    }
}
